@@ -3,5 +3,8 @@ from ._app import set_app_name
 from ._app import on_update
 from ._app import on_app_start
 from ._app import on_app_quit
-from ._menu import menu_item
-from ._settings import settings
+from ._data import StaticData
+from ._data import settings
+from ._gui import window
+from ._gui import menu_item
+
